@@ -222,7 +222,7 @@ fastcpd <- function(  # nolint: cyclomatic complexity
   upper = rep(Inf, p),
   pruning_coef = 0,
   segment_count = 10,
-  trim = 0.02,
+  trim = 0.05,
   momentum_coef = 0,
   multiple_epochs = function(x) 0,
   epsilon = 1e-10,
@@ -376,7 +376,7 @@ fastcpd <- function(  # nolint: cyclomatic complexity
 
   cost_pelt <- NULL
   cost_sen <- NULL
-  if (length(formals(cost)) == 1) {
+  if (!is.null(cost) && length(formals(cost)) == 1) {
     cost_pelt <- cost
   } else {
     cost_sen <- cost
