@@ -57,58 +57,58 @@ constexpr std::array<double, 200> kARMA32 = {
     -0.65013812, 1.89430814,  -1.56479241, -1.08874870, 0.03043624};
 
 // ``` r
-// arima(x, order = c(3, 0, 2), include.mean = FALSE)
+// arima(x, order = c(3, 0, 2), method = "ML", include.mean = FALSE)
 // ```
 constexpr std::array<double, 6> kARMA32PAR = {
-    0.09403583, -0.21094577, 0.64057694, 0.08878535, 0.50335714, 0.976383};
+    0.09403877, -0.21094448, 0.64057698, 0.08878212, 0.50335561, 0.976383};
 constexpr double kARMA32VALUE = 282.2705;
 constexpr std::array<double, 200> kARMA32RESIDUALS = {
-    0.119657519,  1.032474096,  0.272378503,  -0.513466262, 0.360896651,
-    -1.192879019, 1.433102017,  1.973919976,  -0.286092253, -1.068902404,
-    0.420311160,  -0.092947649, 2.484881682,  -0.102348441, 0.694299134,
-    -0.001940191, -0.783191507, 0.160458807,  -1.822138707, 1.445339739,
-    0.149843828,  2.251696352,  0.454279024,  -0.728963510, 0.559105842,
-    -0.966134762, -1.235481261, 0.222442991,  -0.443078439, 0.077838894,
-    0.032441912,  -0.596905740, -0.524275873, -0.167990371, 1.180571667,
-    -1.444230828, 0.568930225,  0.264786828,  1.176883663,  -0.286347443,
-    0.288502676,  0.276749743,  -0.495423915, 1.146055554,  1.153559236,
-    0.786288702,  1.531751169,  0.506444241,  -1.234784305, -0.674854658,
-    -1.319203758, -0.405755195, -0.635780870, 0.006869776,  -0.853813481,
-    0.172526800,  -0.688002195, 1.821840545,  0.761404294,  0.930911151,
-    0.355627614,  1.673152098,  -0.624378265, -0.491415139, 1.337553158,
-    -0.606275222, -0.175528042, -0.520746009, -0.306225934, -0.224190818,
-    0.435620199,  -0.168223465, -0.450724104, 1.282649234,  -0.200834487,
-    -0.105649963, -0.190865851, 0.694058623,  0.011427761,  -0.068304761,
-    -0.747641695, -0.288364059, 0.055643618,  -0.605061321, 0.557105497,
-    -1.514038247, 0.292865107,  -1.545089404, -0.260046835, -0.550001959,
-    -0.617433203, -0.020388020, -1.914096665, 1.184042387,  -1.628003140,
-    -0.402488130, -1.172315731, -0.708756546, 2.149325178,  0.063084092,
-    -1.225579201, -1.719248215, 0.409163368,  0.092147088,  -0.261270269,
-    -0.997034168, -1.469736265, -1.039148546, 0.980849961,  -0.543523639,
-    -1.309963958, 1.779170492,  0.490420881,  -0.084789517, 0.932919342,
-    0.862433833,  -0.471201838, 2.110806263,  -0.320181777, -1.294621935,
-    -0.285838658, 0.117991304,  2.473740888,  0.113743496,  0.369227313,
-    -0.085562152, -0.322310247, -0.099185568, 0.775029832,  2.117880710,
-    1.038558938,  1.188934964,  -1.277658296, 0.923501768,  0.174929192,
-    -1.424358847, 0.439282889,  -0.221313577, 1.563105813,  -0.777733380,
-    -0.495242117, -0.949201880, -0.161960697, 0.390218501,  -0.703796677,
-    0.839591893,  -1.229100273, -1.021043877, 1.399329898,  -0.973579298,
-    0.482653713,  -0.464357456, 0.437588307,  1.747210767,  1.585330654,
-    -0.308262364, -2.320946623, 2.373482023,  0.720108822,  0.683726565,
-    -0.169650185, 0.445895234,  -0.065852182, 0.362627283,  -0.480577366,
-    -1.313740882, 0.934489498,  1.482978448,  -0.175840543, -1.299513687,
-    0.489615625,  0.040886682,  -1.652549176, -0.149360323, -0.632232516,
-    -0.198392944, -1.226626417, 1.764426514,  -0.200280156, -1.568975360,
-    0.050687002,  0.313232606,  -0.848895099, -2.983143430, -0.724349868,
-    0.671856365,  0.053046331,  -0.114494834, 0.557116433,  -1.114710260,
-    1.091938186,  -0.029622117, 0.797372863,  1.016158760,  0.205332961,
-    -0.842645368, 1.100285732,  -2.022265133, -0.499831533, -0.348419523};
+    0.119657408,  1.032473704,  0.272376942,  -0.513467899, 0.360895835,
+    -1.192880996, 1.433100166,  1.973922066,  -0.286091638, -1.068905105,
+    0.420306848,  -0.092951436, 2.484883335,  -0.102345183, 0.694294107,
+    -0.001945305, -0.783193088, 0.160456193,  -1.822140989, 1.445338741,
+    0.149844825,  2.251697123,  0.454280147,  -0.728966478, 0.559100547,
+    -0.966137311, -1.235482332, 0.222442392,  -0.443079174, 0.077839927,
+    0.032445119,  -0.596906088, -0.524277031, -0.167988007, 1.180573061,
+    -1.444229846, 0.568932014,  0.264786853,  1.176882560,  -0.286343959,
+    0.288503044,  0.276744804,  -0.495424595, 1.146057717,  1.153557308,
+    0.786286620,  1.531751912,  0.506440764,  -1.234790578, -0.674857496,
+    -1.319207187, -0.405758548, -0.635777671, 0.006872234,  -0.853814223,
+    0.172529006,  -0.687999003, 1.821840720,  0.761406944,  0.930913649,
+    0.355625927,  1.673148403,  -0.624379803, -0.491417044, 1.337549093,
+    -0.606278432, -0.175527827, -0.520746379, -0.306230794, -0.224191200,
+    0.435623968,  -0.168224381, -0.450725594, 1.282651139,  -0.200834469,
+    -0.105651058, -0.190864937, 0.694056412,  0.011426560,  -0.068302094,
+    -0.747642931, -0.288368026, 0.055645114,  -0.605058777, 0.557104707,
+    -1.514037514, 0.292866223,  -1.545088726, -0.260045877, -0.549998796,
+    -0.617430793, -0.020385573, -1.914093097, 1.184044158,  -1.628000096,
+    -0.402484407, -1.172312334, -0.708755400, 2.149329038,  0.063091100,
+    -1.225576779, -1.719249381, 0.409161913,  0.092150142,  -0.261263212,
+    -0.997031624, -1.469739057, -1.039146694, 0.980856089,  -0.543519749,
+    -1.309960879, 1.779173562,  0.490421840,  -0.084786515, 0.932923390,
+    0.862430019,  -0.471204686, 2.110810084,  -0.320183872, -1.294628320,
+    -0.285838057, 0.117989406,  2.473737718,  0.113749269,  0.369227302,
+    -0.085570702, -0.322313197, -0.099184080, 0.775027234,  2.117878532,
+    1.038560466,  1.188933066,  -1.277664314, 0.923495622,  0.174926126,
+    -1.424360706, 0.439281014,  -0.221316503, 1.563104058,  -0.777730196,
+    -0.495243442, -0.949207280, -0.161961302, 0.390221806,  -0.703795583,
+    0.839591621,  -1.229099166, -1.021043933, 1.399330431,  -0.973577378,
+    0.482655660,  -0.464355484, 0.437586625,  1.747211428,  1.585334370,
+    -0.308263370, -2.320951195, 2.373477690,  0.720107605,  0.683728936,
+    -0.169649076, 0.445887060,  -0.065857428, 0.362630920,  -0.480579045,
+    -1.313747291, 0.934489800,  1.482980398,  -0.175841430, -1.299513016,
+    0.489612611,  0.040881864,  -1.652545737, -0.149356969, -0.632237208,
+    -0.198392678, -1.226618346, 1.764426591,  -0.200281576, -1.568969725,
+    0.050688596,  0.313228026,  -0.848891876, -2.983136285, -0.724352905,
+    0.671855094,  0.053057034,  -0.114486630, 0.557114459,  -1.114710564,
+    1.091942955,  -0.029619865, 0.797371683,  1.016160892,  0.205333539,
+    -0.842648400, 1.100284213,  -2.022265971, -0.499833359, -0.348418497};
 
 context("GetNllPelt Unit Test") {
   test_that("arma(3, 2) is correct for 200 data points") {
     const std::tuple<mat, mat, double> cost_result = FastcpdTest::GetNllPelt(
         colvec(kARMA32.data(), kARMA32.size()), 0, 199, false, R_NilValue);
-    const colvec par = std::get<0>(cost_result).as_col();
+    const colvec par = std::get<0>(cost_result);
     const colvec residuals = std::get<1>(cost_result).as_col();
     const double value = std::get<2>(cost_result);
 
