@@ -1,8 +1,6 @@
 testthat::test_that(
   "examples/data-uk_seatbelts.R", {
     testthat::skip_if_not_installed("ggplot2")
-    testthat::skip_if_not_installed("lubridate")
-    testthat::skip_if_not_installed("zoo")
 
     source("examples/data-uk_seatbelts.R")
     testthat::expect_equal(result_ar@cp_set, c(71, 158))
